@@ -3,8 +3,8 @@ spBwplot <- function(inp, x, cond = NULL, horizontal = TRUE,
                      do.out = FALSE, ...) {
   
   ## initializations
-  if ( !class(inp) == "synthPopObj" ) {
-    stop("input argument 'inp' must be of class 'synthPopObj'!\n")
+  if ( !class(inp) == "simPopObj" ) {
+    stop("input argument 'inp' must be of class 'simPopObj'!\n")
   }
   
   weights.pop <- inp@pop@weight
